@@ -1,14 +1,13 @@
-package Net::IP::Match;
-
-require 5.005_62;
+use 5.008;
 use strict;
 use warnings;
+
+package Net::IP::Match;
+our $VERSION = '1.100860';
+# ABSTRACT: Efficiently match IP addresses against IP ranges
 use Filter::Simple;
-
-our $VERSION = '0.03';
-
 FILTER sub {
-    	s[\b __MATCH_IP \s* \( (.*?) \s* , \s* (.*?) \s* \) ]
+    s[\b __MATCH_IP \s* \( (.*?) \s* , \s* (.*?) \s* \) ]
 	 [
 	    my @n = eval $2;
 	    my @t;
@@ -37,23 +36,29 @@ FILTER sub {
 	    }
 
 	 ]gsex;
-	 print if $::debug;
+    print if $::debug;
 };
-
 1;
+
+
 __END__
+=pod
 
 =head1 NAME
 
 Net::IP::Match - Efficiently match IP addresses against IP ranges
 
+=head1 VERSION
+
+version 1.100860
+
 =head1 SYNOPSIS
 
   use Net::IP::Match;
 
   if(__MATCH_IP($_, qw{10.0.0.0/8 87.134.66.128
     87.134.87.0/24 145.97.0.0/16})) {
-    	...
+    	# ...
   }
 
 =head1 DESCRIPTION
@@ -148,39 +153,39 @@ would have to call it as a function, which would add the stack
 overhead. Richard Clamp had the interesting idea of optimizing the
 generated opcode tree.
 
-=head1 TAGS
+=head1 INSTALLATION
 
-If you talk about this module in blogs, on del.icio.us or anywhere else,
-please use the C<netipmatch> tag.
+See perlmodinstall for information and options on installing Perl modules.
 
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
 
-Please report any bugs or feature requests to
-C<bug-net-ip-match@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org>.
-
-=head1 INSTALLATION
-
-See perlmodinstall for information and options on installing Perl modules.
+Please report any bugs or feature requests through the web interface at
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=Net-IP-Match>.
 
 =head1 AVAILABILITY
 
 The latest version of this module is available from the Comprehensive Perl
-Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
-site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
+Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
+site near you, or see
+L<http://search.cpan.org/dist/Net-IP-Match/>.
+
+The development version lives at
+L<http://github.com/hanekomu/Net-IP-Match/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
 
 =head1 AUTHOR
 
-Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
+  Marcel Gruenauer <marcel@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2002-2007 by Marcel GrE<uuml>nauer
+This software is copyright (c) 2002 by Marcel Gruenauer.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
